#ifndef CENTIPEDESCRIPT_H
#define CENTIPEDESCRIPT_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qmainwindow.h>
#include <qcombobox.h>

#include <vector>
#include <math.h>
#include "conffile.h"

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QAction;
class QActionGroup;
class QToolBar;
class QPopupMenu;
class QGroupBox;
class QPushButton;
class QListBox;
class QListBoxItem;
class QLabel;
class QLineEdit;
class QComboBox;

class CentipedeScript : public QMainWindow
{
    Q_OBJECT

public:
    	CentipedeScript( QWidget* parent = 0, const char* name = 0, WFlags fl = WType_TopLevel );
    	~CentipedeScript();

    	QGroupBox* groupBox2;
    	QPushButton* buttonAdd;
    	QPushButton* buttonDel;
    	QListBox* listModules;
    	QLabel* pixImage;
    	QGroupBox* groupBox3;
    	QLineEdit* lineConfiguration;
	QGroupBox* groupBox3_2;
    	QComboBox* comboScenario;
    	QPushButton* buttonExit;
    	QPushButton* buttonGenerate;

protected:
    	QVBoxLayout* CentipedeScriptLayout;
    	QSpacerItem* spacer6_2;
    	QSpacerItem* spacer4;
    	QSpacerItem* spacer6;
    	QHBoxLayout* layout3;
    	QSpacerItem* spacer5;

    	void closeEvent( QCloseEvent* );

protected slots:
    	virtual void languageChange();

private slots:
	void save();
	void saveAs();
	void addModule();
	void delModule();
	void changedModule(int index);

private:
	QPixmap image0;
	QPixmap image1;
	QString filename;
	std::vector<int> robotConf;
	std::vector<ConfFile> cf;

	void readConfFile( QString );
	QString getConfFile();
	void readConfScriptFile( QString );
	void generate(QTextStream *t);
	int writeToWorld( QString origin, QTextStream *destination );
	void writeWorld( QTextStream *t );
	void writeHeader( QTextStream *t );
	void writeGround( QTextStream *t );
	void writeGridGround( QTextStream *t );
	void writeFly( QTextStream *t );
	void writeWater( QTextStream *t ); 
	void writeAquarium( QTextStream *t ); 
	void writeDefSmallSegment( QTextStream *t );
	void writeDefBigSegment( QTextStream *t );
	void writeCameras( QTextStream *t );
	void writeLeg( QTextStream *t, int leg_number );
	void writeRigidLeg( QTextStream *t, int leg_number );
	void writeInfiniteGround( QTextStream *t );
	void writeInfiniteWater( QTextStream *t );
	int isLeg( QString );
};

#endif // CENTIPEDESCRIPT_H
